@@ -2,13 +2,21 @@
  * Fragment storage.
  *
  * Fragments are stored in keyed buckets.
- * A bucket is an ordered list of unique, indexed packets.
+ * A packet bucket is an ordered list of unique, indexed packets,
+ * intended for eventual reassembly into a complete packet.
  * It is up to the caller to free a bucket when it is
  * no longer needed. Very old buckets are deleted automatically.
  */
 
-#include <stdlib.h>
-#include <err.h>
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#if STDC_HEADERS
+# include <stdlib.h>
+#endif
+
+#include "compat.h"
 
 #define LIST_REMOVE(o, pfx) do {				\
 	if ((*(o)->pfx##_prevp = (o)->pfx##_next) != NULL)	\
