@@ -1,11 +1,22 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: loop.c,v 1.5 2004/05/24 10:38:46 d Exp $ */
+/* $Id: loop.c 978 2006-01-27 15:01:08Z d $ */
 
-#include <stdio.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/socket.h>
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
 
+#if STDC_HEADERS
+# include <stdio.h>
+# include <string.h>
+#endif
+#if HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
+#if HAVE_SYS_SOCKET_H
+# include <sys/socket.h>
+#endif
+
+#include "compat.h"
 #include "tag.h"
 #include "flow.h"
 
