@@ -1,20 +1,46 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: main.c,v 1.60 2004/11/06 06:39:31 d Exp $ */
+/* $Id: main.c 978 2006-01-27 15:01:08Z d $ */
 
 /*
  * The main module. Here we process command line arguments, and
  * interface pcap to our tag and flow display modules.
  */
 
-#include <stdio.h>
-#include <unistd.h>
-#include <stdlib.h>
-#include <err.h>
-#include <errno.h>
-#include <pcap.h>
-#include <poll.h>
-#include <sys/time.h>
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
 
+#if STDC_HEADERS
+# include <stdio.h>
+# include <stdlib.h>
+#endif
+#if HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+
+#if HAVE_ERRNO_H
+# include <errno.h>
+#endif
+
+#if HAVE_PCAP_H
+# include <pcap.h>
+#endif
+#if HAVE_POLL_H
+# include <poll.h>
+#endif
+
+#if TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# if HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
+
+#include "compat.h"
 #include "main.h"
 #include "tag.h"
 #include "flow.h"
@@ -37,8 +63,7 @@ int Tflag = 0;
 int wflag = 5;
 
 /* Current release version */
-#define VERSION "1.7.5"
-char version[] = VERSION;
+char version[] = PACKAGE_VERSION;
 
 /* The system time when the current packet capture cycle started */
 static struct timeval starttime;
