@@ -1,9 +1,18 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: ppp.c,v 1.6 2004/03/13 16:50:49 d Exp $ */
+/* $Id: ppp.c 978 2006-01-27 15:01:08Z d $ */
 
-#include <pcap.h>
-#include <net/ppp_defs.h>
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
 
+#if HAVE_PCAP_H
+# include <pcap.h>
+#endif
+#if HAVE_NET_PPP_DEFS_H
+# include <net/ppp_defs.h>
+#endif
+
+#include "compat.h"
 #include "tag.h"
 #include "flow.h"
 
