@@ -1,5 +1,5 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: resize.c,v 1.5 2004/03/13 16:47:01 d Exp $ */
+/* $Id: resize.c 978 2006-01-27 15:01:08Z d $ */
 
 /*
  * This compilation unit provides a callback mechanism for display.c
@@ -7,20 +7,40 @@
  * here in case system-independent window resizing becomes complicated.
  */
 
-#include <stdio.h>
-#include <unistd.h>
-#include <curses.h>
-#include <signal.h>
-#include <sys/ioctl.h>
-#include <termios.h>
-#include <err.h>
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
 
-static void sigwinch(int sig);
+#if STDC_HEADERS
+# include <stdio.h>
+#endif
+#if HAVE_UNISTD_H
+# include <unistd.h>
+#endif
+#if HAVE_CURSES_H
+# include <curses.h>
+#endif
+#if HAVE_SIGNAL_H
+# include <signal.h>
+#endif
+#if HAVE_SYS_SIGNAL_H
+# include <sys/signal.h>
+#endif
+#if HAVE_TERMIOS_H
+# include <termios.h>
+#endif
+#if HAVE_SYS_IOCTL_H
+# include <sys/ioctl.h>
+#endif
+
+#include "compat.h"
+
+static RETSIGTYPE sigwinch();
 
 static volatile int *flagp = NULL;
 
 /* Set the flag when the window size changes */
-static void
+static RETSIGTYPE
 sigwinch(sig)
 	int sig;
 {
@@ -35,8 +55,10 @@ resize_init(fp)
 {
 	flagp = fp;
 	*flagp = 0;
+#ifndef SIGWINCH
 	if (signal(SIGWINCH, sigwinch) == SIG_ERR)
 		err(1, "signal");
+#endif
 }
 
 /* This should be called when the flag has been set by the sigwinch handler */
