@@ -1,9 +1,17 @@
 /* David Leonard, 2002. Public domain. */
-/* $Id: tag.c,v 1.2 2004/03/13 16:47:11 d Exp $ */
+/* $Id: tag.c 978 2006-01-27 15:01:08Z d $ */
 
-#include <stdio.h>
-#include <unistd.h>
-#include <string.h>
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#if STDC_HEADERS
+# include <stdio.h>
+# include <string.h>
+#endif
+#if HAVE_UNISTD_H
+# include <unistd.h>
+#endif
 
 #include "main.h"
 #include "tag.h"
@@ -13,8 +21,11 @@
 /*
  * Combine source and dest to make a combined tag unless -c flag given
  * What combining means is that we sometimes have flows which are not
- * directional. So we cnovert a->b and b->a tags to get a<->b. The left and
- * right sides are sorted lexicographically, so that tags are unambiguous.
+ * uni-directional. So we convert a->b and b->a tags to get a<->b. The left and
+ * right sides are ordered lexicographically, so that we get only a<->b and
+ * not also b<->a.
+ * XXX the ordering should be biased to have the local host/net on the left
+ * of combined flows.
  */
 const char *
 tag_combine(src, dst)
