@@ -1,7 +1,14 @@
 /* David Leonard, 2004. Public domain. */
-/* $Id: wol.c,v 1.2 2004/11/06 06:53:15 d Exp $ */
+/* $Id: wol.c 978 2006-01-27 15:01:08Z d $ */
+
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#if STDC_HEADERS
+# include <stdio.h>
+#endif
 
-#include <stdio.h>
 #include "tag.h"
 #include "flow.h"
 
